==> libosl_0.5.0.orig.tar.gz: libosl_0.5.0.orig/doc/html/search/classes_72.js <==
var searchData=
[
  ['random_3c_20unsigned_20int_20_3e',['Random< unsigned int >',['../structosl_1_1misc_1_1Random_3_01unsigned_01int_01_4.html',1,'osl::misc']]],
  ['random_3c_20unsigned_20long_20long_20_3e',['Random< unsigned long long >',['../structosl_1_1misc_1_1Random_3_01unsigned_01long_01long_01_4.html',1,'osl::misc']]],
  ['randomplayer',['RandomPlayer',['../classosl_1_1game__playing_1_1RandomPlayer.html',1,'osl::game_playing']]],
  ['ratedmove',['RatedMove',['../classosl_1_1rating_1_1RatedMove.html',1,'osl::rating']]],
  ['ratedmovevector',['RatedMoveVector',['../classosl_1_1rating_1_1RatedMoveVector.html',1,'osl::rating']]],
  ['ratingdiff',['RatingDiff',['../structosl_1_1RatingDiff.html',1,'osl']]],
  ['ratingdiffrange',['RatingDiffRange',['../structosl_1_1RatingDiffRange.html',1,'osl']]],
  ['ratingenv',['RatingEnv',['../classosl_1_1rating_1_1RatingEnv.html',1,'osl::rating']]],
  ['ratio',['Ratio',['../classosl_1_1stat_1_1Ratio.html',1,'osl::stat']]],
  ['realizationprobability',['RealizationProbability',['../structosl_1_1search_1_1RealizationProbability.html',1,'osl::search']]],
  ['record',['Record',['../classosl_1_1record_1_1Record.html',1,'osl::record']]],
  ['recorder',['Recorder',['../structosl_1_1search_1_1SearchRecorder_1_1Recorder.html',1,'osl::search::SearchRecorder']]],
  ['recordprinter',['RecordPrinter',['../structRecordPrinter.html',1,'']]],
  ['recordprinter2',['RecordPrinter2',['../structRecordPrinter2.html',1,'']]],
  ['recordset',['RecordSet',['../classosl_1_1search_1_1analyzer_1_1RecordSet.html',1,'osl::search::analyzer']]],
  ['recordstack2',['RecordStack2',['../classosl_1_1search_1_1RecordStack2.html',1,'osl::search']]],
  ['recordtracer',['RecordTracer',['../classosl_1_1game__playing_1_1RecordTracer.html',1,'osl::game_playing']]],
  ['recordvisitor',['RecordVisitor',['../classosl_1_1record_1_1RecordVisitor.html',1,'osl::record']]],
  ['recordvisitorobserver',['RecordVisitorObserver',['../classosl_1_1record_1_1RecordVisitorObserver.html',1,'osl::record']]],
  ['relativekingx',['RelativeKingX',['../classosl_1_1rating_1_1RelativeKingX.html',1,'osl::rating']]],
  ['relativekingxgroup',['RelativeKingXGroup',['../structosl_1_1rating_1_1RelativeKingXGroup.html',1,'osl::rating']]],
  ['relativekingy',['RelativeKingY',['../classosl_1_1rating_1_1RelativeKingY.html',1,'osl::rating']]],
  ['relativekingygroup',['RelativeKingYGroup',['../structosl_1_1rating_1_1RelativeKingYGroup.html',1,'osl::rating']]],
  ['reorder',['Reorder',['../structosl_1_1misc_1_1Reorder.html',1,'osl::misc']]],
  ['repetitioncounter',['RepetitionCounter',['../classosl_1_1RepetitionCounter.html',1,'osl']]],
  ['resignplayer',['ResignPlayer',['../classosl_1_1game__playing_1_1ResignPlayer.html',1,'osl::game_playing']]],
  ['result',['Result',['../structResult.html',1,'']]],
  ['result',['Result',['../structosl_1_1Sennichite_1_1Result.html',1,'osl::Sennichite']]],
  ['resultvector',['ResultVector',['../classosl_1_1game__playing_1_1SpeculativeAllMoves_1_1ResultVector.html',1,'osl::game_playing::SpeculativeAllMoves']]],
  ['richpredictor',['RichPredictor',['../classosl_1_1threatmate_1_1RichPredictor.html',1,'osl::threatmate']]],
  ['rookattack',['RookAttack',['../classosl_1_1move__probability_1_1RookAttack.html',1,'osl::move_probability']]],
  ['rookdefense',['RookDefense',['../classosl_1_1rating_1_1RookDefense.html',1,'osl::rating']]],
  ['rookeffect',['RookEffect',['../classosl_1_1eval_1_1ml_1_1RookEffect.html',1,'osl::eval::ml']]],
  ['rookeffectbase',['RookEffectBase',['../classosl_1_1eval_1_1ml_1_1RookEffectBase.html',1,'osl::eval::ml']]],
  ['rookeffectpiece',['RookEffectPiece',['../classosl_1_1eval_1_1ml_1_1RookEffectPiece.html',1,'osl::eval::ml']]],
  ['rookeffectpiecekingrelative',['RookEffectPieceKingRelative',['../classosl_1_1eval_1_1ml_1_1RookEffectPieceKingRelative.html',1,'osl::eval::ml']]],
  ['rookmobility',['RookMobility',['../structosl_1_1mobility_1_1RookMobility.html',1,'osl::mobility']]],
  ['rookmobility',['RookMobility',['../classosl_1_1eval_1_1ml_1_1RookMobility.html',1,'osl::eval::ml']]],
  ['rookmobilityall',['RookMobilityAll',['../classosl_1_1eval_1_1ml_1_1RookMobilityAll.html',1,'osl::eval::ml']]],
  ['rookmobilitysum',['RookMobilitySum',['../classosl_1_1eval_1_1ml_1_1RookMobilitySum.html',1,'osl::eval::ml']]],
  ['rookmobilitysumkingx',['RookMobilitySumKingX',['../classosl_1_1eval_1_1ml_1_1RookMobilitySumKingX.html',1,'osl::eval::ml']]],
  ['rookmobilityx',['RookMobilityX',['../classosl_1_1eval_1_1ml_1_1RookMobilityX.html',1,'osl::eval::ml']]],
  ['rookmobilityxkingx',['RookMobilityXKingX',['../classosl_1_1eval_1_1ml_1_1RookMobilityXKingX.html',1,'osl::eval::ml']]],
  ['rookmobilityy',['RookMobilityY',['../classosl_1_1eval_1_1ml_1_1RookMobilityY.html',1,'osl::eval::ml']]],
  ['rookpawn',['RookPawn',['../classosl_1_1eval_1_1ml_1_1RookPawn.html',1,'osl::eval::ml']]],
  ['rookpawn_3c_20false_20_3e',['RookPawn< false >',['../classosl_1_1eval_1_1ml_1_1RookPawn.html',1,'osl::eval::ml']]],
  ['rookpawn_3c_20true_20_3e',['RookPawn< true >',['../classosl_1_1eval_1_1ml_1_1RookPawn.html',1,'osl::eval::ml']]],
  ['rookpawnending',['RookPawnEnding',['../classosl_1_1eval_1_1ml_1_1RookPawnEnding.html',1,'osl::eval::ml']]],
  ['rookpawnopening',['RookPawnOpening',['../classosl_1_1eval_1_1ml_1_1RookPawnOpening.html',1,'osl::eval::ml']]],
  ['rookpawny',['RookPawnY',['../classosl_1_1eval_1_1ml_1_1RookPawnY.html',1,'osl::eval::ml']]],
  ['rookpawnyx',['RookPawnYX',['../classosl_1_1eval_1_1ml_1_1RookPawnYX.html',1,'osl::eval::ml']]],
  ['rookpromotedefense',['RookPromoteDefense',['../classosl_1_1eval_1_1ml_1_1RookPromoteDefense.html',1,'osl::eval::ml']]],
  ['rookpromotedefenserookh',['RookPromoteDefenseRookH',['../classosl_1_1eval_1_1ml_1_1RookPromoteDefenseRookH.html',1,'osl::eval::ml']]],
  ['rookrook',['RookRook',['../classosl_1_1eval_1_1ml_1_1RookRook.html',1,'osl::eval::ml']]],
  ['rookrookpiece',['RookRookPiece',['../classosl_1_1eval_1_1ml_1_1RookRookPiece.html',1,'osl::eval::ml']]],
  ['rooksilverknight',['RookSilverKnight',['../classosl_1_1eval_1_1ml_1_1RookSilverKnight.html',1,'osl::eval::ml']]],
  ['rookyending',['RookYEnding',['../classosl_1_1eval_1_1ml_1_1RookYEnding.html',1,'osl::eval::ml']]],
  ['rookyopening',['RookYOpening',['../classosl_1_1eval_1_1ml_1_1RookYOpening.html',1,'osl::eval::ml']]],
  ['rootcenter',['RootCenter',['../classRootCenter.html',1,'']]],
  ['rootpv',['RootPV',['../structosl_1_1search_1_1RootPV.html',1,'osl::search']]],
  ['rootstatenotset',['RootStateNotSet',['../structosl_1_1ntesuki_1_1RootStateNotSet.html',1,'osl::ntesuki']]],
  ['roottable',['RootTable',['../structosl_1_1search_1_1HashRejections_1_1RootTable.html',1,'osl::search::HashRejections']]],
  ['runner',['Runner',['../structosl_1_1misc_1_1NonBlockDelete_1_1Runner.html',1,'osl::misc::NonBlockDelete']]],
  ['runner',['Runner',['../structosl_1_1game__playing_1_1SpeculativeAllMoves_1_1Runner.html',1,'osl::game_playing::SpeculativeAllMoves']]],
  ['russiancharacters',['RussianCharacters',['../structosl_1_1record_1_1RussianCharacters.html',1,'osl::record']]],
  ['rzone',['Rzone',['../classosl_1_1ntesuki_1_1Rzone.html',1,'osl::ntesuki']]]
];

==> libosl_0.6.0.orig.tar.gz: libosl_0.6.0.orig/doc/html/search/classes_72.js <==
var searchData=
[
  ['random',['Random',['../structosl_1_1misc_1_1Random.html',1,'osl::misc']]],
  ['random_3c_20unsigned_20int_20_3e',['Random&lt; unsigned int &gt;',['../structosl_1_1misc_1_1Random_3_01unsigned_01int_01_4.html',1,'osl::misc']]],
  ['random_3c_20unsigned_20long_20long_20_3e',['Random&lt; unsigned long long &gt;',['../structosl_1_1misc_1_1Random_3_01unsigned_01long_01long_01_4.html',1,'osl::misc']]],
  ['randomplayer',['RandomPlayer',['../classosl_1_1game__playing_1_1RandomPlayer.html',1,'osl::game_playing']]],
  ['ratedmove',['RatedMove',['../classosl_1_1rating_1_1RatedMove.html',1,'osl::rating']]],
  ['ratedmovevector',['RatedMoveVector',['../classosl_1_1rating_1_1RatedMoveVector.html',1,'osl::rating']]],
  ['ratingdiff',['RatingDiff',['../structosl_1_1RatingDiff.html',1,'osl']]],
  ['ratingdiffrange',['RatingDiffRange',['../structosl_1_1RatingDiffRange.html',1,'osl']]],
  ['ratingenv',['RatingEnv',['../classosl_1_1rating_1_1RatingEnv.html',1,'osl::rating']]],
  ['ratio',['Ratio',['../classosl_1_1stat_1_1Ratio.html',1,'osl::stat']]],
  ['realizationprobability',['RealizationProbability',['../structosl_1_1search_1_1RealizationProbability.html',1,'osl::search']]],
  ['record',['Record',['../classosl_1_1record_1_1Record.html',1,'osl::record']]],
  ['recorder',['Recorder',['../structosl_1_1search_1_1SearchRecorder_1_1Recorder.html',1,'osl::search::SearchRecorder']]],
  ['recordprinter',['RecordPrinter',['../structRecordPrinter.html',1,'']]],
  ['recordprinter2',['RecordPrinter2',['../structRecordPrinter2.html',1,'']]],
  ['recordset',['RecordSet',['../classosl_1_1search_1_1analyzer_1_1RecordSet.html',1,'osl::search::analyzer']]],
  ['recordstack2',['RecordStack2',['../classosl_1_1search_1_1RecordStack2.html',1,'osl::search']]],
  ['recordtracer',['RecordTracer',['../classosl_1_1game__playing_1_1RecordTracer.html',1,'osl::game_playing']]],
  ['recordvisitor',['RecordVisitor',['../classosl_1_1record_1_1RecordVisitor.html',1,'osl::record']]],
  ['recordvisitorobserver',['RecordVisitorObserver',['../classosl_1_1record_1_1RecordVisitorObserver.html',1,'osl::record']]],
  ['relativekingx',['RelativeKingX',['../classosl_1_1rating_1_1RelativeKingX.html',1,'osl::rating']]],
  ['relativekingxgroup',['RelativeKingXGroup',['../structosl_1_1rating_1_1RelativeKingXGroup.html',1,'osl::rating']]],
  ['relativekingy',['RelativeKingY',['../classosl_1_1rating_1_1RelativeKingY.html',1,'osl::rating']]],
  ['relativekingygroup',['RelativeKingYGroup',['../structosl_1_1rating_1_1RelativeKingYGroup.html',1,'osl::rating']]],
  ['reorder',['Reorder',['../structosl_1_1misc_1_1Reorder.html',1,'osl::misc']]],
  ['repetitionanalyzer',['RepetitionAnalyzer',['../classosl_1_1annotate_1_1RepetitionAnalyzer.html',1,'osl::annotate']]],
  ['repetitioncounter',['RepetitionCounter',['../classosl_1_1RepetitionCounter.html',1,'osl']]],
  ['resignplayer',['ResignPlayer',['../classosl_1_1game__playing_1_1ResignPlayer.html',1,'osl::game_playing']]],
  ['result',['Result',['../structResult.html',1,'']]],
  ['result',['Result',['../structosl_1_1Sennichite_1_1Result.html',1,'osl::Sennichite']]],
  ['resultvector',['ResultVector',['../classosl_1_1game__playing_1_1SpeculativeAllMoves_1_1ResultVector.html',1,'osl::game_playing::SpeculativeAllMoves']]],
  ['richpredictor',['RichPredictor',['../classosl_1_1threatmate_1_1RichPredictor.html',1,'osl::threatmate']]],
  ['rookattack',['RookAttack',['../classosl_1_1move__probability_1_1RookAttack.html',1,'osl::move_probability']]],
  ['rookdefense',['RookDefense',['../classosl_1_1rating_1_1RookDefense.html',1,'osl::rating']]],
  ['rookeffect',['RookEffect',['../classosl_1_1eval_1_1ml_1_1RookEffect.html',1,'osl::eval::ml']]],
  ['rookeffectbase',['RookEffectBase',['../classosl_1_1eval_1_1ml_1_1RookEffectBase.html',1,'osl::eval::ml']]],
  ['rookeffectpiece',['RookEffectPiece',['../classosl_1_1eval_1_1ml_1_1RookEffectPiece.html',1,'osl::eval::ml']]],
  ['rookeffectpiecekingrelative',['RookEffectPieceKingRelative',['../classosl_1_1eval_1_1ml_1_1RookEffectPieceKingRelative.html',1,'osl::eval::ml']]],
  ['rookmobility',['RookMobility',['../classosl_1_1eval_1_1ml_1_1RookMobility.html',1,'osl::eval::ml']]],
  ['rookmobility',['RookMobility',['../structosl_1_1mobility_1_1RookMobility.html',1,'osl::mobility']]],
  ['rookmobilityall',['RookMobilityAll',['../classosl_1_1eval_1_1ml_1_1RookMobilityAll.html',1,'osl::eval::ml']]],
  ['rookmobilitysum',['RookMobilitySum',['../classosl_1_1eval_1_1ml_1_1RookMobilitySum.html',1,'osl::eval::ml']]],
  ['rookmobilitysumkingx',['RookMobilitySumKingX',['../classosl_1_1eval_1_1ml_1_1RookMobilitySumKingX.html',1,'osl::eval::ml']]],
  ['rookmobilityx',['RookMobilityX',['../classosl_1_1eval_1_1ml_1_1RookMobilityX.html',1,'osl::eval::ml']]],
  ['rookmobilityxkingx',['RookMobilityXKingX',['../classosl_1_1eval_1_1ml_1_1RookMobilityXKingX.html',1,'osl::eval::ml']]],
  ['rookmobilityy',['RookMobilityY',['../classosl_1_1eval_1_1ml_1_1RookMobilityY.html',1,'osl::eval::ml']]],
  ['rookpawn',['RookPawn',['../classosl_1_1eval_1_1ml_1_1RookPawn.html',1,'osl::eval::ml']]],
  ['rookpawn_3c_20false_20_3e',['RookPawn&lt; false &gt;',['../classosl_1_1eval_1_1ml_1_1RookPawn.html',1,'osl::eval::ml']]],
  ['rookpawn_3c_20true_20_3e',['RookPawn&lt; true &gt;',['../classosl_1_1eval_1_1ml_1_1RookPawn.html',1,'osl::eval::ml']]],
  ['rookpawnending',['RookPawnEnding',['../classosl_1_1eval_1_1ml_1_1RookPawnEnding.html',1,'osl::eval::ml']]],
  ['rookpawnopening',['RookPawnOpening',['../classosl_1_1eval_1_1ml_1_1RookPawnOpening.html',1,'osl::eval::ml']]],
  ['rookpawny',['RookPawnY',['../classosl_1_1eval_1_1ml_1_1RookPawnY.html',1,'osl::eval::ml']]],
  ['rookpawnyx',['RookPawnYX',['../classosl_1_1eval_1_1ml_1_1RookPawnYX.html',1,'osl::eval::ml']]],
  ['rookpromotedefense',['RookPromoteDefense',['../classosl_1_1eval_1_1ml_1_1RookPromoteDefense.html',1,'osl::eval::ml']]],
  ['rookpromotedefenserookh',['RookPromoteDefenseRookH',['../classosl_1_1eval_1_1ml_1_1RookPromoteDefenseRookH.html',1,'osl::eval::ml']]],
  ['rookrook',['RookRook',['../classosl_1_1eval_1_1ml_1_1RookRook.html',1,'osl::eval::ml']]],
  ['rookrookpiece',['RookRookPiece',['../classosl_1_1eval_1_1ml_1_1RookRookPiece.html',1,'osl::eval::ml']]],
  ['rooksilverknight',['RookSilverKnight',['../classosl_1_1eval_1_1ml_1_1RookSilverKnight.html',1,'osl::eval::ml']]],
  ['rookyending',['RookYEnding',['../classosl_1_1eval_1_1ml_1_1RookYEnding.html',1,'osl::eval::ml']]],
  ['rookyopening',['RookYOpening',['../classosl_1_1eval_1_1ml_1_1RookYOpening.html',1,'osl::eval::ml']]],
  ['rootcenter',['RootCenter',['../classRootCenter.html',1,'']]],
  ['rootpv',['RootPV',['../structosl_1_1search_1_1RootPV.html',1,'osl::search']]],
  ['rootstatenotset',['RootStateNotSet',['../structosl_1_1ntesuki_1_1RootStateNotSet.html',1,'osl::ntesuki']]],
  ['roottable',['RootTable',['../structosl_1_1search_1_1HashRejections_1_1RootTable.html',1,'osl::search::HashRejections']]],
  ['runner',['Runner',['../structosl_1_1misc_1_1NonBlockDelete_1_1Runner.html',1,'osl::misc::NonBlockDelete']]],
  ['runner',['Runner',['../structosl_1_1game__playing_1_1SpeculativeAllMoves_1_1Runner.html',1,'osl::game_playing::SpeculativeAllMoves']]],
  ['russiancharacters',['RussianCharacters',['../structosl_1_1record_1_1RussianCharacters.html',1,'osl::record']]],
  ['rzone',['Rzone',['../classosl_1_1ntesuki_1_1Rzone.html',1,'osl::ntesuki']]]
];
